/***************************************************************************
                          kdlgmain.cpp  -  description
                             -------------------
    begin                : Sat Jun 17 2000
    copyright            : (C) 2000 by sva
    email                : svanpo@cybercable.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include	<qdir.h>
#include	<qfile.h>
#include	<stdio.h>
#include	<stdlib.h>
#include	<dirent.h>
#include	<sys/types.h>
#include	<qdatetime.h>
#include	<qtabdialog.h>
#include 	"kdlgmain.h"
#include 	"kdlgstat.h"
#include 	"kdlgabout.h"
#include 	"kdlgstatipaddress.h"
#include 	"ktabconfgeneral.h"
#include 	"ktabconfplugins.h"

// +------------------------------------------------------------------------------------+
// | KDlgMain::KDlgMain(QWidget *parent, const char *name)								|
// |																					|
// | Constructor                                                                        |
// |																					|
// | Input : parent			: parent widget												|
// |		 name			: name of the widget										|
// | Output: nothing																	|
// +------------------------------------------------------------------------------------+
KDlgMain::KDlgMain(QWidget *parent, const char *name)
{
	initDialog();
	initControls();
	initMenu();
	readConfFile();

	bzero(&mLast, sizeof(mLast));
	bzero(&mToday, sizeof(mToday));
	bzero(&mMonth, sizeof(mMonth));

	setTitle();
	reset_analyser_session();

	mTimer = new QTimer();
	connect(mTimer, SIGNAL(timeout()), SLOT(timerTimeout()));
	mTimer->start(mRefreshRate*1000);
}

// +------------------------------------------------------------------------------------+
// | KDlgMain::~KDlgMain()																|
// |																					|
// | Destructor																			|
// +------------------------------------------------------------------------------------+
KDlgMain::~KDlgMain()
{
}

// +------------------------------------------------------------------------------------+
// | sgNetworkInfos KDlgMain::readNetDeviceInfo(char *iDev)								|
// |																					|
// | Read network adapter's informations in the /proc/net/dev file						|
// |																					|
// | Input : iDev			: network adapter to read									|
// | Output: nothing																	|
// | Return: sgNetworkInfos	: struct with data											|
// +------------------------------------------------------------------------------------+
sgNetworkInfos KDlgMain::readNetDeviceInfo(char *iDev)
{
	FILE			*lFile;
	char			lDev[100];
	char			lLine[1025];
	char			lValue[100];
	char			*lIndexChar;
	char			*lIndexValue;
	char			lIndexField;
	sgNetworkInfos  lNetworkInfos;

	sprintf(lDev, "%s:", iDev);

	lFile = fopen("/proc/net/dev", "rt");
	if (lFile!=NULL)
	{
		// Ignore 2 lines (title)
		fgets(lLine, sizeof(lLine)-1, lFile);
		fgets(lLine, sizeof(lLine)-1, lFile);
		while (!feof(lFile))
		{
			fgets(lLine, sizeof(lLine)-1, lFile);
			if (strstr(lLine, lDev))
			{
				lIndexChar=lLine;
				// Find the begin of data
				while ((*lIndexChar!=':') && (*lIndexChar!=0)) lIndexChar++;

				if (*lIndexChar==':')
				{
					lIndexChar++;
					for (lIndexField=0; lIndexField<16; lIndexField++)
					{
						lIndexValue=lValue;
						while (*lIndexChar==' ') lIndexChar++;
						while ((*lIndexChar!=' ') && (*lIndexChar!=0))
								*(lIndexValue++)=*(lIndexChar++);
						*(lIndexValue++)=0;
						switch(lIndexField)
						{
							case  0: {lNetworkInfos.rBytes 		= atoi(lValue);}; break;
							case  1: {lNetworkInfos.rPackets 	= atoi(lValue);}; break;
							case  2: {lNetworkInfos.rErrs 		= atoi(lValue);}; break;
							case  3: {lNetworkInfos.rDrop 		= atoi(lValue);}; break;
							case  4: {lNetworkInfos.rFifo 		= atoi(lValue);}; break;
							case  5: {lNetworkInfos.rFrame 		= atoi(lValue);}; break;
							case  6: {lNetworkInfos.rCompressed	= atoi(lValue);}; break;
							case  7: {lNetworkInfos.rMulticast 	= atoi(lValue);}; break;
							case  8: {lNetworkInfos.tBytes 		= atoi(lValue);}; break;
							case  9: {lNetworkInfos.tPackets 	= atoi(lValue);}; break;
							case 10: {lNetworkInfos.tErrs 		= atoi(lValue);}; break;
							case 11: {lNetworkInfos.tDrop 		= atoi(lValue);}; break;
							case 12: {lNetworkInfos.tFifo 		= atoi(lValue);}; break;
							case 13: {lNetworkInfos.tColls 		= atoi(lValue);}; break;
							case 14: {lNetworkInfos.tCarrier 	= atoi(lValue);}; break;
							case 15: {lNetworkInfos.tCompressed	= atoi(lValue);}; break;
						}
					}
				}
				break;
			}
		}
		fclose(lFile);
	}
	else fprintf(stderr, i18n("Can't open /proc/dev/net directory.\n"));

	return(lNetworkInfos);
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::timerTimeout(void)													|
// |																					|
// | Refresh informations and call the function to save data for statistics				|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::timerTimeout(void)
{
	sgNetworkInfos 	lNetworkInfos;
	char			lValue[100];
	char			lFindFile[NAME_MAX+1];
	char			lActualFile[NAME_MAX+1];
	int				lType;
	float			lSize;
	DIR 			*lOpenDir;
	struct dirent	*lEntry;
	sgValue			lValueFile;
	QDir			lDir(QDir::homeDirPath());
	QDate 			lDate = QDate::currentDate();
	QString 		lPath;
	QString 		lFullPath;
	QString			lFullPathTemp;
	static bool		lFirst=true;
	static QDate	lDateOfDay(2000,1,1);

	lNetworkInfos = readNetDeviceInfo((char *)(const char *)mNetworkAdapter);

	// +--------------------------------------------------------------------------+
	// |                        Actual Linux session                              |
	// +--------------------------------------------------------------------------+
	// Upload for the session
	lSize = (float)lNetworkInfos.tBytes;
	lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
	switch(lType)
	{
		case 0 : {sprintf(lValue, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
		case 1 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
		case 2 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
		case 3 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
		case 4 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
		default: sprintf(lValue, "%0.2f %s", lSize, i18n("b "));
	}
	mUEditLinuxSession->setText(lValue);
	// Download for the session
	lSize = (float)lNetworkInfos.rBytes;
	lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
	switch(lType)
	{
		case 0 : {sprintf(lValue, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
		case 1 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
		case 2 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
		case 3 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
		case 4 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
		default: sprintf(lValue, "%0.2f %s", lSize, i18n("b "));
	}
	mDEditLinuxSession->setText(lValue);

	// +--------------------------------------------------------------------------+
	// |                       Actual U/D Analyser session                        |
	// +--------------------------------------------------------------------------+
	// Upload for the U/D Analyser session
	lSize = (float)(lNetworkInfos.tBytes - mStart.upload);
	lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
	switch(lType)
	{
		case 0 : {sprintf(lValue, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
		case 1 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
		case 2 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
		case 3 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
		case 4 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
		default: sprintf(lValue, "%0.2f %s", lSize, i18n("b "));
	}
	mUEditAnalyserSession->setText(lValue);
	// Download for the U/D Analyser session
	lSize = (float)(lNetworkInfos.rBytes - mStart.download);
	lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
	switch(lType)
	{
		case 0 : {sprintf(lValue, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
		case 1 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
		case 2 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
		case 3 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
		case 4 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
		default: sprintf(lValue, "%0.2f %s", lSize, i18n("b "));
	}
	mDEditAnalyserSession->setText(lValue);

	// +--------------------------------------------------------------------------+
	// |                                   Today                                  |
	// +--------------------------------------------------------------------------+
	if (lFirst)
	{
		mLast.upload 	= lNetworkInfos.tBytes;
		mLast.download 	= lNetworkInfos.rBytes;
		lFirst=false;
	}

	bzero(&lValueFile, sizeof(sgValue));

	lDir.mkdir(".ud_Analyser");
	if (lDir.cd(".ud_Analyser"))
	{
		lDir.mkdir("data");
		if (lDir.cd("data"))
		{
			lFullPath.sprintf("%s/%04d-%02d-%02d", (const char *)lDir.absPath(), lDate.year(), lDate.month(), lDate.day());
			lFullPathTemp.sprintf("%s/~%04d-%02d-%02d", (const char *)lDir.absPath(), lDate.year(), lDate.month(), lDate.day());

			// Read statistics of the day
			QFile lFile(lFullPath);
			if (lFile.open(IO_Raw | IO_ReadOnly))
			{
				if (lFile.readBlock((char *)&lValueFile, sizeof(sgValue))==sizeof(sgValue))
				{
					lValueFile.upload 	= lValueFile.upload + lNetworkInfos.tBytes - mLast.upload;
					lValueFile.download = lValueFile.download + lNetworkInfos.rBytes - mLast.download;
					lFile.close();

					// Don't save if no change
					if ( ((lNetworkInfos.tBytes-mLast.upload)!=0) || ((lNetworkInfos.rBytes - mLast.download)!=0) )
					{
						lDir.rename(lFullPath, lFullPathTemp);
			
						// Write new statistics of the day
						QFile lFile2(lFullPath);
						if (lFile2.open(IO_Raw | IO_WriteOnly))
						{
							if (lFile2.writeBlock((const char *)&lValueFile, sizeof(sgValue))==sizeof(sgValue))
							{
								lDir.remove(lFullPathTemp);
							}
							else
							{
								lDir.rename(lFullPathTemp, lFullPath);
							}
							lFile2.close();
						}
					}

					mToday.upload = lValueFile.upload;
					mToday.download = lValueFile.download;
					mLast.upload 	= lNetworkInfos.tBytes;
					mLast.download	= lNetworkInfos.rBytes;
				}
				else
				{
					lFile.close();
				}
			}
			else
			{
				QFile lFile2(lFullPath);
				if (lFile2.open(IO_Raw | IO_WriteOnly))
				{
					lFile2.writeBlock((const char *)&lValueFile, sizeof(sgValue));
					lFile2.close();
				}
			}
		}
	}

	// Upload for today
	lSize = (float)lValueFile.upload;
	lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
	switch(lType)
	{
		case 0 : {sprintf(lValue, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
		case 1 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
		case 2 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
		case 3 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
		case 4 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
		default: sprintf(lValue, "%0.2f %s", lSize, i18n("b "));
	}
	mUEditToday->setText(lValue);
	// Download for today
	lSize = (float)lValueFile.download;
	lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
	switch(lType)
	{
		case 0 : {sprintf(lValue, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
		case 1 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
		case 2 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
		case 3 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
		case 4 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
		default: sprintf(lValue, "%0.2f %s", lSize, i18n("b "));
	}
	mDEditToday->setText(lValue);

	// +--------------------------------------------------------------------------+
	// |                              Current Month                               |
	// +--------------------------------------------------------------------------+
	if (lDateOfDay!=QDate::currentDate())
	{
		mMonth.upload = 0;
		mMonth.download = 0;
		lDateOfDay = QDate::currentDate();
		lOpenDir = opendir((const char *)lDir.absPath());
		if (lOpenDir!=NULL)
		{
			sprintf(lFindFile, "%04d-%02d-", lDateOfDay.year(), lDateOfDay.month());
			sprintf(lActualFile, "%04d-%02d-%02d", lDateOfDay.year(), lDateOfDay.month(), lDateOfDay.day());
			while ((lEntry=readdir(lOpenDir)) != NULL)
			{
				if (strncmp(lEntry->d_name, lFindFile, strlen(lFindFile))==0)
				{
					if (strncmp(lEntry->d_name, lActualFile, strlen(lActualFile))!=0)
					{
						//fprintf(stderr, "%s\n", lEntry->d_name);
						lFullPath.sprintf("%s/%s", (const char *)lDir.absPath(), lEntry->d_name);

						QFile lFile2(lFullPath);
						if (lFile2.open(IO_Raw | IO_ReadOnly))
						{
							if (lFile2.readBlock((char *)&lValueFile, sizeof(sgValue))==sizeof(sgValue))
							{
								mMonth.upload 	+= lValueFile.upload;
								mMonth.download	+= lValueFile.download;
							}

							lFile2.close();
						}
					}
				}
			}
			closedir(lOpenDir);
		}
	}

	// Upload for the month
	lSize = (float)(mMonth.upload+mToday.upload);
	lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
	switch(lType)
	{
		case 0 : {sprintf(lValue, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
		case 1 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
		case 2 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
		case 3 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
		case 4 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
		default: sprintf(lValue, "%0.2f %s", lSize, i18n("b "));
	}
	mUEditCurrentMonth->setText(lValue);
	// Download for the month
	lSize = (float)(mMonth.download+mToday.download);
	lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
	switch(lType)
	{
		case 0 : {sprintf(lValue, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
		case 1 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
		case 2 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
		case 3 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
		case 4 : {sprintf(lValue, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
		default: sprintf(lValue, "%0.2f %s", lSize, i18n("b "));
	}
	mDEditCurrentMonth->setText(lValue);
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::initMenu(void)														|
// |																					|
// | Initialize the menu bar															|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::initMenu(void)
{
  	QPopupMenu	*fileMenu = new QPopupMenu();
  	fileMenu->insertItem(i18n("&Quit"), this, SLOT(quit()));
	
  	QPopupMenu	*statsMenu = new QPopupMenu();
  	statsMenu->insertItem(i18n("&Upload/download ..."), this, SLOT(stat_upload_download()));
  	//statsMenu->insertItem(i18n("&IP address evolution ..."), this, SLOT(stat_ip_address()));
  	statsMenu->insertSeparator();
  	statsMenu->insertItem(i18n("&Reset the U/D Analyser session"), this, SLOT(reset_analyser_session()));

  	QPopupMenu	*optionMenu = new QPopupMenu();
  	optionMenu->insertItem(i18n("&Configuration ..."), this, SLOT(configuration()));

  	QPopupMenu	*helpMenu = new QPopupMenu();
  	helpMenu->insertItem(i18n("&About ..."), this, SLOT(about()));

    mMenubar = new KMenuBar( this );
  	mMenubar->insertItem(i18n("&File"), fileMenu);
  	mMenubar->insertItem(i18n("&Statistiques"), statsMenu);
  	mMenubar->insertItem(i18n("&Options"), optionMenu);
  	mMenubar->insertSeparator();
  	mMenubar->insertItem(i18n("&Help"), helpMenu);
	setMenu(mMenubar);
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::quit(void)															|
// |																					|
// | Quit the application																|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::quit(void)
{
	kapp->quit();
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::reset_analyser_session(void)										|
// |																					|
// | Reset the U/D Analyser session statistics											|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::reset_analyser_session(void)
{	
	sgNetworkInfos 	lNetworkInfos;
	lNetworkInfos 	= readNetDeviceInfo((char *)(const char *)mNetworkAdapter);
	mStart.upload 	= lNetworkInfos.tBytes;
	mStart.download	= lNetworkInfos.rBytes;
	timerTimeout();
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::stat_upload_download(void)											|
// |																					|
// | Display upload/download statistics for a month										|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::stat_upload_download(void)
{	
	KDlgStat			*dlgStat = new KDlgStat;

	if (dlgStat->exec()==QDialog::Accepted)
	{
	}
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::stat_ip_address(void)												|
// |																					|
// | Display ip address statistics for a month				  							|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::stat_ip_address(void)
{	
	KDlgStatIPAddress	*dlgStat = new KDlgStatIPAddress;

	if (dlgStat->exec()==QDialog::Accepted)
	{
	}
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::configuration(void)													|
// |																					|
// | Display the configuration box of the application									|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::configuration(void)
{	
	KConfig			*lConfig;
	QTabDialog		*dlgConfiguration = new QTabDialog(this, 0, TRUE);
	KTabConfGeneral	*tabConfGeneral = new KTabConfGeneral;
	KTabConfPlugins	*tabConfPlugins = new KTabConfPlugins;

	dlgConfiguration->setMaximumSize(50,50);
	dlgConfiguration->setMinimumSize(50,50);
	dlgConfiguration->setFixedSize(50,50);

	dlgConfiguration->setCaption(i18n("Configuration"));
	dlgConfiguration->addTab(tabConfGeneral, i18n("General"));
	dlgConfiguration->addTab(tabConfPlugins, i18n("Plugins"));
    dlgConfiguration->setOkButton(i18n("OK"));
	dlgConfiguration->setCancelButton(i18n("Cancel"));
	if (dlgConfiguration->exec()==QDialog::Accepted)
	{	
		// Refresh rate modified
		if (tabConfGeneral->mSliderRefreshRate->value()!=mRefreshRate)
		{
			mRefreshRate = tabConfGeneral->mSliderRefreshRate->value();
			mTimer->changeInterval(mRefreshRate*1000);
		}

		// Network adapter modified
		if (mNetworkAdapter != tabConfGeneral->mComboBoxNetworkAdapter->text(tabConfGeneral->mComboBoxNetworkAdapter->currentItem()))
		{
			mNetworkAdapter = tabConfGeneral->mComboBoxNetworkAdapter->text(tabConfGeneral->mComboBoxNetworkAdapter->currentItem());
			sgNetworkInfos 	lNetworkInfos;
			lNetworkInfos 	= readNetDeviceInfo((char *)(const char *)mNetworkAdapter);
			mStart.upload 	= lNetworkInfos.tBytes;
			mStart.download	= lNetworkInfos.rBytes;
			timerTimeout();
		}

		lConfig = kapp->getConfig();
		lConfig->setGroup("General");
		lConfig->writeEntry("Network adapter", (const char *)mNetworkAdapter);
		lConfig->writeEntry("Refresh rate", (int)mRefreshRate);
		lConfig->writeEntry("Linux session", (bool)(tabConfGeneral->mCheckBoxLinuxSession->isChecked()));
		lConfig->writeEntry("U/D Analyser session", (bool)(tabConfGeneral->mCheckBoxUDAnalyserSession->isChecked()));
		lConfig->writeEntry("Today", (bool)(tabConfGeneral->mCheckBoxToday->isChecked()));
		lConfig->writeEntry("Current month", (bool)(tabConfGeneral->mCheckBoxCurrentMonth->isChecked()));

		lConfig->sync();

		readConfFile();

		setTitle();
	}
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::about(void)															|
// |																					|
// | Display the about box of the application											|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::about(void)
{
	KDlgAbout	*dlgAbout = new KDlgAbout;

	if (dlgAbout->exec()==QDialog::Accepted)
	{
	}
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::readConfFile(void)													|
// |																					|
// | Load the configuration file														|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::readConfFile(void)
{
	KConfig			*lConfig;
	int				lY;

	lConfig = kapp->getConfig();

	// Find the network adapter in the combo box
	lConfig->setGroup("General");
	mNetworkAdapter = lConfig->readEntry("Network adapter", "lo");
	mRefreshRate = lConfig->readNumEntry("Refresh rate", 5);

	// Change controls positions ...
	lY = 20;
	//		... for Linux session
	if (lConfig->readBoolEntry("Linux session", true))
	{
		mUStaticLinuxSession->move(mUStaticLinuxSession->x(), lY);
		mUEditLinuxSession->move(mUEditLinuxSession->x(), lY);
		mUStaticLinuxSession->show();
		mUEditLinuxSession->show();
		lY += 20;
	}
	else
	{
		mUStaticLinuxSession->hide();
		mUEditLinuxSession->hide();
	}
	//		... for U/D Analyser session
	if (lConfig->readBoolEntry("U/D Analyser session", true))
	{
		mUStaticAnalyserSession->move(mUStaticAnalyserSession->x(), lY);
		mUEditAnalyserSession->move(mUEditAnalyserSession->x(), lY);
		mUStaticAnalyserSession->show();
		mUEditAnalyserSession->show();
		lY += 20;
	}
	else
	{
		mUStaticAnalyserSession->hide();
		mUEditAnalyserSession->hide();
	}
	//		... for today
	if (lConfig->readBoolEntry("Today", true))
	{
		mUStaticToday->move(mUStaticToday->x(), lY);
		mUEditToday->move(mUEditToday->x(), lY);
		mUStaticToday->show();
		mUEditToday->show();
		lY += 20;
	}
	else
	{
		mUStaticToday->hide();
		mUEditToday->hide();
	}
	//		... for current month
	if (lConfig->readBoolEntry("Current month", true))
	{
		mUStaticCurrentMonth->move(mUStaticCurrentMonth->x(), lY);
		mUEditCurrentMonth->move(mUEditCurrentMonth->x(), lY);
		mUStaticCurrentMonth->show();
		mUEditCurrentMonth->show();
		lY += 20;
	}
	else
	{
		mUStaticCurrentMonth->hide();
		mUEditCurrentMonth->hide();
	}
	mGroupUpload->setFixedHeight(lY+10);

	lY = 20;
	//		... for Linux session
	if (lConfig->readBoolEntry("Linux session", true))
	{
		mDStaticLinuxSession->move(mDStaticLinuxSession->x(), lY);
		mDEditLinuxSession->move(mDEditLinuxSession->x(), lY);
		mDStaticLinuxSession->show();
		mDEditLinuxSession->show();
		lY += 20;
	}
	else
	{
		mDStaticLinuxSession->hide();
		mDEditLinuxSession->hide();
	}
	//		... for U/D Analyser session
	if (lConfig->readBoolEntry("U/D Analyser session", true))
	{
		mDStaticAnalyserSession->move(mDStaticAnalyserSession->x(), lY);
		mDEditAnalyserSession->move(mDEditAnalyserSession->x(), lY);
		mDStaticAnalyserSession->show();
		mDEditAnalyserSession->show();
		lY += 20;
	}
	else
	{
		mDStaticAnalyserSession->hide();
		mDEditAnalyserSession->hide();
	}
	//		... for today
	if (lConfig->readBoolEntry("Today", true))
	{
		mDStaticToday->move(mDStaticToday->x(), lY);
		mDEditToday->move(mDEditToday->x(), lY);
		mDStaticToday->show();
		mDEditToday->show();
		lY += 20;
	}
	else
	{
		mDStaticToday->hide();
		mDEditToday->hide();
	}
	//		... for current month
	if (lConfig->readBoolEntry("Current month", true))
	{
		mDStaticCurrentMonth->move(mDStaticCurrentMonth->x(), lY);
		mDEditCurrentMonth->move(mDEditCurrentMonth->x(), lY);
		mDStaticCurrentMonth->show();
		mDEditCurrentMonth->show();
		lY += 20;
	}
	else
	{
		mDStaticCurrentMonth->hide();
		mDEditCurrentMonth->hide();
	}
	mGroupDownload->setFixedHeight(lY+10);

	setFixedHeight(lY+50);
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::initControls(void)													|
// |																					|
// | Initialize some personnals controls 												|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::initControls(void)
{
	mUEditLinuxSession= new KLineEdit(mGroupUpload,"UEditLinuxSession");
  	mUEditLinuxSession->setGeometry(120,20,80,20);
  	mUEditLinuxSession->setMinimumSize(0,0);
  	mUEditLinuxSession->setFont(QFont("courier", 12, QFont::DemiBold));

  	mDEditLinuxSession= new KLineEdit(mGroupDownload,"DEditLinuxSession");
  	mDEditLinuxSession->setGeometry(120,20,80,20);
  	mDEditLinuxSession->setMinimumSize(0,0);
  	mDEditLinuxSession->setFont(QFont("courier", 12, QFont::DemiBold));

  	mUEditAnalyserSession= new KLineEdit(mGroupUpload,"UEditAnalyserSession");
  	mUEditAnalyserSession->setGeometry(120,40,80,20);
  	mUEditAnalyserSession->setMinimumSize(0,0);
  	mUEditAnalyserSession->setFont(QFont("courier", 12, QFont::DemiBold));

  	mDEditAnalyserSession= new KLineEdit(mGroupDownload,"DEditAnalyserSession");
  	mDEditAnalyserSession->setGeometry(120,40,80,20);
  	mDEditAnalyserSession->setMinimumSize(0,0);
  	mDEditAnalyserSession->setFont(QFont("courier", 12, QFont::DemiBold));

  	mUEditToday= new KLineEdit(mGroupUpload,"UEditToday");
  	mUEditToday->setGeometry(120,60,80,20);
  	mUEditToday->setMinimumSize(0,0);
  	mUEditToday->setFont(QFont("courier", 12, QFont::DemiBold));

  	mDEditToday= new KLineEdit(mGroupDownload,"DEditToday");
  	mDEditToday->setGeometry(120,60,80,20);
  	mDEditToday->setMinimumSize(0,0);
  	mDEditToday->setFont(QFont("courier", 12, QFont::DemiBold));

  	mUEditCurrentMonth= new KLineEdit(mGroupUpload,"UEditCurrentMonth");
  	mUEditCurrentMonth->setGeometry(120,80,80,20);
  	mUEditCurrentMonth->setMinimumSize(0,0);
  	mUEditCurrentMonth->setFont(QFont("courier", 12, QFont::DemiBold));

  	mDEditCurrentMonth= new KLineEdit(mGroupDownload,"DEditCurrentMonth");
  	mDEditCurrentMonth->setGeometry(120,80,80,20);
  	mDEditCurrentMonth->setMinimumSize(0,0);
  	mDEditCurrentMonth->setFont(QFont("courier", 12, QFont::DemiBold));
}

// +------------------------------------------------------------------------------------+
// | void KDlgMain::setTitle(void)														|
// |																					|
// | Change the title of the window														|
// |																					|
// | Input : nothing																	|
// | Output: nothing																	|
// | Return: nothing																	|
// +------------------------------------------------------------------------------------+
void KDlgMain::setTitle(void)
{
	QString title("Upload/Download Analyser v0.8.1");
	title += " - ";
	title += mNetworkAdapter;
	setCaption((const char *)title);
}
