/***************************************************************************
                          kdlgstat.cpp  -  description
                             -------------------
    begin                : Thu Jul 20 2000
    copyright            : (C) 2000 by sva
    email                : svanpo@cybercable.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include <kapp.h>
#include <qdir.h>
#include <stdio.h>
#include <stdlib.h>
#include "kdlgmain.h"
#include "kdlgstat.h"

KDlgStat::KDlgStat(QWidget *parent, const char *name) : QDialog(parent,name,true)
{
	QString		lTitle;

	initDialog();

	setCaption(i18n("Upload/download"));

	// QListBox
	mListBoxMonth->hide();
  	mGraphMonth= new KStatGraph(this,"Graph");
  	mGraphMonth->setGeometry(10,50,510,200);
  	mUDValues= new KListBox(this,"Values");
  	mUDValues->setGeometry(10,260,510,130);
	lTitle = i18n("Day num.");
	lTitle += "|";
	lTitle += i18n("Day");
	lTitle += "|";
	lTitle += i18n("Upload");
	lTitle += "|";
	lTitle += i18n("Download");
	mUDValues->setColumns((char *)(const char *)lTitle);
	mUDValues->setAlignments("C|L|R|R");
	mUDValues->setSizes("80|94|160|160");
	mUDValues->setAlternatedColor1(QColor(200,200,200));
	mUDValues->setAlternatedColor1(QColor(240,240,240));

	readYears();
	activatedYear(0);
	connect(mComboBoxYear, SIGNAL(activated(int)), SLOT(activatedYear(int)));
	connect(mComboBoxMonth, SIGNAL(activated(int)), SLOT(activatedMonth(int)));
	connect(mPushButtonOk, SIGNAL(clicked()), SLOT(reject()));
}

KDlgStat::~KDlgStat()
{
}

void KDlgStat::readYears(void)
{
	QDir				lDir(QDir::home());
	const QFileInfoList	*lInfoList;
	QString				lFilename;
	char				lYear[5];
	int					lLastYear;

	mComboBoxYear->clear();

	lDir.cd(".ud_Analyser/data");
	lDir.setNameFilter("????-*");
	lInfoList = lDir.entryInfoList();

  	QFileInfoListIterator it(*lInfoList);      // create list iterator
	QFileInfo *fi;                          // pointer for traversing

	lLastYear = 0;
	while ( (fi=it.current()) )
	{           // for each file...
		//fprintf(stderr, "%10li %s\n", fi->size(), fi->fileName().data() );
		if (strlen(fi->fileName().data())==10)
		{
			lFilename = fi->fileName();
			if (lFilename.mid(4, 1)=="-")
			{
				// QComboBox
				bzero(lYear, 5);
				strncpy(lYear, lFilename, 4);
				if (atoi(lYear)!=lLastYear)
				{
					lLastYear = atoi(lYear);
					mComboBoxYear->insertItem(lYear);
				}
			}
		}
		++it;                               // goto next list element
	}
}

void KDlgStat::activatedMonth(int index)
{
	// Refresh the graph
	mGraphMonth->drawGraph(	atoi(mListBoxMonth->text(mComboBoxMonth->currentItem())),
							atoi(mComboBoxYear->text(mComboBoxYear->currentItem())));

	loadUDList();
}

void KDlgStat::activatedYear(int index)
{
	QDir				lDir(QDir::home());
	const QFileInfoList	*lInfoList;
	QString				lFilename;
	char				lFilter[50];
	char				lMonth[3];
	int					lLastMonth;

	mComboBoxMonth->clear();
	mListBoxMonth->clear();
	sprintf(lFilter, "%s-??-??", mComboBoxYear->text(index));

	lDir.cd(".ud_Analyser/data");
	lDir.setNameFilter(lFilter);
	lInfoList = lDir.entryInfoList();

  	QFileInfoListIterator it(*lInfoList);      // create list iterator
	QFileInfo *fi;                          // pointer for traversing

	lLastMonth = 0;
	while ( (fi=it.current()) )
	{           // for each file...
		//fprintf(stderr, "%10li %s\n", fi->size(), fi->fileName().data() );
		lFilename = fi->fileName();
		strcpy(lMonth, lFilename.mid(5, 2));
		if (atoi(lMonth)!=lLastMonth)
		{
			lLastMonth = atoi(lMonth);
			switch(lLastMonth)
			{
				case 1  : {mComboBoxMonth->insertItem(i18n("January"));mListBoxMonth->insertItem("1");} break;
				case 2  : {mComboBoxMonth->insertItem(i18n("February"));mListBoxMonth->insertItem("2");} break;
				case 3  : {mComboBoxMonth->insertItem(i18n("March"));mListBoxMonth->insertItem("3");} break;
				case 4  : {mComboBoxMonth->insertItem(i18n("April"));mListBoxMonth->insertItem("4");} break;
				case 5  : {mComboBoxMonth->insertItem(i18n("May"));mListBoxMonth->insertItem("5");} break;
				case 6  : {mComboBoxMonth->insertItem(i18n("June"));mListBoxMonth->insertItem("6");} break;
				case 7  : {mComboBoxMonth->insertItem(i18n("July"));mListBoxMonth->insertItem("7");} break;
				case 8  : {mComboBoxMonth->insertItem(i18n("August"));mListBoxMonth->insertItem("8");} break;
				case 9  : {mComboBoxMonth->insertItem(i18n("September"));mListBoxMonth->insertItem("9");} break;
				case 10 : {mComboBoxMonth->insertItem(i18n("October"));mListBoxMonth->insertItem("10");} break;
				case 11 : {mComboBoxMonth->insertItem(i18n("November"));mListBoxMonth->insertItem("11");} break;
				case 12 : {mComboBoxMonth->insertItem(i18n("December"));mListBoxMonth->insertItem("12");} break;
			}
		}
		++it;                               // goto next list element
	}

	// Refresh the graph
	mGraphMonth->drawGraph(	atoi(mListBoxMonth->text(mComboBoxMonth->currentItem())),
							atoi(mComboBoxYear->text(mComboBoxYear->currentItem())));

	loadUDList();
}

void KDlgStat::loadUDList(void)
{
	QDir		lDir(QDir::home());
	QDate		lDate;
	QString		lLibDay;
	int			lNumDays;
	int			liDay;
	int			lMonth;
	int			lYear;
	sgValue		lValue;
	QString		lFullPath;
	QString		lLine;
	float		lSize;
	int			lType;
	char		lUStrVal[50];
	char		lDStrVal[50];

	lMonth 	= atoi(mListBoxMonth->text(mComboBoxMonth->currentItem()));
	lYear 	= atoi(mComboBoxYear->text(mComboBoxYear->currentItem()));

	mUDValues->clear();
	if (lDir.cd(".ud_Analyser/data"))
	{
		// Find the number of days for a month
		switch(lMonth)
		{
			case 1  : lNumDays=31; break;
			case 2  : {
						QDate	lDate;
						if (lDate.isValid(29,2,lYear))	lNumDays = 29;
						else							lNumDays = 28;
						break;
					  }
			case 3  : lNumDays=31; break;
			case 4  : lNumDays=30; break;
			case 5  : lNumDays=31; break;
			case 6  : lNumDays=30; break;
			case 7  : lNumDays=31; break;
			case 8  : lNumDays=31; break;
			case 9  : lNumDays=30; break;
			case 10 : lNumDays=31; break;
			case 11 : lNumDays=30; break;
			case 12 : lNumDays=31; break;
			default: lNumDays=31;
		}

		for (liDay=0; liDay<lNumDays; liDay++)
		{
			// Read statistics of the day
			lFullPath.sprintf("%s/%04d-%02d-%02d", (const char *)lDir.absPath(), lYear, lMonth, liDay+1);
			QFile lFile(lFullPath);
			if (lFile.open(IO_Raw | IO_ReadOnly))
			{
				if (lFile.readBlock((char *)&lValue, sizeof(sgValue))==sizeof(sgValue))
				{	// QString
					// Upload
					lSize = (float)lValue.upload;
					lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
					switch(lType)
					{
						case 0 : {sprintf(lUStrVal, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
						case 1 : {sprintf(lUStrVal, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
						case 2 : {sprintf(lUStrVal, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
						case 3 : {sprintf(lUStrVal, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
						case 4 : {sprintf(lUStrVal, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
						default: sprintf(lUStrVal, "%0.2f %s", lSize, i18n("b "));
					}
					// Download
					lSize = (float)lValue.download;
					lType=0; while (lSize>=1024) {lSize=lSize/1024; lType++;}
					switch(lType)
					{
						case 0 : {sprintf(lDStrVal, "%0.2f %s", lSize, i18n("b "));}; break; 	// Bytes
						case 1 : {sprintf(lDStrVal, "%0.2f %s", lSize, i18n("Kb"));}; break; 	// Kb
						case 2 : {sprintf(lDStrVal, "%0.2f %s", lSize, i18n("Mb"));}; break; 	// Mb
						case 3 : {sprintf(lDStrVal, "%0.2f %s", lSize, i18n("Gb"));}; break; 	// Gb
						case 4 : {sprintf(lDStrVal, "%0.2f %s", lSize, i18n("Tb"));}; break; 	// Tb
						default: sprintf(lDStrVal, "%0.2f %s", lSize, i18n("b "));
					}

					lDate = QDate(lYear, lMonth, liDay+1);
					switch(lDate.dayOfWeek())
					{
						case 1 : lLibDay = i18n("Monday"); break;
						case 2 : lLibDay = i18n("Tuesday"); break;
						case 3 : lLibDay = i18n("Wednesday"); break;
						case 4 : lLibDay = i18n("Thursday"); break;
						case 5 : lLibDay = i18n("Friday"); break;
						case 6 : lLibDay = i18n("Saturday"); break;
						case 7 : lLibDay = i18n("Sunday"); break;
					} // QListBox
					lLine.sprintf("%02d|%s|%s|%s", liDay+1, (char *)(const char *)lLibDay, lUStrVal, lDStrVal);
					mUDValues->insert((char *)(const char *)lLine);
				}
				lFile.close();
			}
		}
		
	}
}
