/***************************************************************************
                          kstatgraph.cpp  -  description
                             -------------------
    begin                : Sun Jul 23 2000
    copyright            : (C) 2000 by sva
    email                : svanpo@cybercable.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <qdir.h>
#include <string.h>
#include <qpainter.h>
#include <qdatetime.h>
#include "kdlgmain.h"
#include "kstatgraph.h"

#include "upload.xpm"
#include "download.xpm"

KStatGraph::KStatGraph(QWidget *parent, const char *name ) : QWidget(parent,name)
{
	mYear = 2000;
	mMonth= 1;
}

KStatGraph::~KStatGraph()
{
}

void KStatGraph::paintEvent(QPaintEvent *e)
{
	QDir		lDir(QDir::home());
	QPainter	p(this);
	QBrush		lBrushWhite(QColor(255,255,255));
	QPen		lPenBlack(QColor(0,0,0));
	QPen		lPenLightGrey(QColor(200,200,200));
	QString		lFullPath;
	QString		lValue;
	int			lNumDays;
	int			lWidth;
	int			lHeight;
	int			lX, lY;
	int			lX1, lY1, lW1, lH1;
	int			lX2, lY2, lW2, lH2;
	float		lXStep, lUYStep, lDYStep;
	double		lGrad;
	int			lXOrigin, lYOrigin;
	int			liValue;
	sgValue		lValues[31];
	char		lDay[5];
	double		lMaxUpload;
	double		lMaxDownload;
	int			lType;

	if (lDir.cd(".ud_Analyser/data"))
	{

		// Find the number of days for a month
		switch(mMonth)
		{
			case 1  : lNumDays=31; break;
			case 2  : {
						QDate	lDate;
						if (lDate.isValid(29,2,mYear))	lNumDays = 29;
						else							lNumDays = 28;
						break;
					  }
			case 3  : lNumDays=31; break;
			case 4  : lNumDays=30; break;
			case 5  : lNumDays=31; break;
			case 6  : lNumDays=30; break;
			case 7  : lNumDays=31; break;
			case 8  : lNumDays=31; break;
			case 9  : lNumDays=30; break;
			case 10 : lNumDays=31; break;
			case 11 : lNumDays=30; break;
			case 12 : lNumDays=31; break;
			default: lNumDays=31;
		}

		// Draw background
		p.setPen(QPen(QColor(0,0,0)));
		p.fillRect(0,0,width()-1,height()-1, QBrush(QColor(255,255,255)));
		p.drawRect(0,0,width()-1,height()-1);

		// Draw the vertical lines and days
		liValue 	= 0;
		lMaxUpload 	= 1;
		lMaxDownload= 1;
		lXOrigin 	= 60;
		lYOrigin 	= height()-20;
		lWidth 		= width()-1-lXOrigin*2;
		lHeight		= lYOrigin-11;
		lXStep 		= (float)lWidth / (lNumDays+1);
		p.fillRect(lXOrigin, lYOrigin, lWidth, -lHeight-1, QBrush(QColor(240,240,240)));
		p.setFont(QFont("Helvetica", 8));
		for (lX=0; lX<lNumDays; lX++)
		{
			bzero(&lValues[liValue], sizeof(sgValue));
			p.setPen(QPen(QColor(200,200,200)));
			p.drawLine(lXOrigin+(lX+1)*lXStep, lYOrigin, lXOrigin+(lX+1)*lXStep, lYOrigin-lHeight);

			sprintf(lDay, "%d", lX+1);
			p.setPen(QPen(QColor(0,0,0)));
			if (lX&1)	p.drawText(lXOrigin+(lX+1)*lXStep-6, lYOrigin+5, 13, 10, AlignCenter, lDay);
			else		p.drawText(lXOrigin+(lX+1)*lXStep-6, lYOrigin+5-4, 13, 10, AlignCenter, lDay);

			// Read statistics of the day
			lFullPath.sprintf("%s/%04d-%02d-%02d", (const char *)lDir.absPath(), mYear, mMonth, liValue+1);
			QFile lFile(lFullPath);
			if (lFile.open(IO_Raw | IO_ReadOnly))
			{
				if (lFile.readBlock((char *)&lValues[liValue], sizeof(sgValue))==sizeof(sgValue))
				{
					if (lValues[liValue].upload>lMaxUpload) 	lMaxUpload=lValues[liValue].upload;
					if (lValues[liValue].download>lMaxDownload)	lMaxDownload=lValues[liValue].download;
				}
				lFile.close();
			}

			liValue++;
		}

		double lUMaxHeight2=2;
		while (lUMaxHeight2<lMaxUpload) lUMaxHeight2=lUMaxHeight2*2;
		lUYStep = (float)lHeight/lUMaxHeight2;
		double lDMaxHeight2=2;
		while (lDMaxHeight2<lMaxDownload) lDMaxHeight2=lDMaxHeight2*2;
		lDYStep = (float)lHeight/lDMaxHeight2;
		// Draw horiz lines
		p.setPen(QPen(QColor(200,200,200)));
		for (lY=0; lY<5; lY++)
		{
			p.drawLine(lXOrigin, lYOrigin-lY*((float)lHeight/4), lXOrigin+lWidth, lYOrigin-lY*((float)lHeight/4));
		}

		// Draw chart
		for (lX=0; lX<lNumDays; lX++)
		{
			// Display upload
			lH1 = -(int)(lUYStep*lValues[lX].upload);
			lX1 = (int)(lXOrigin+lXStep*lX+lXStep-3);
			lY1 = lYOrigin;
			lW1 = 3;
			p.fillRect(lX1, lY1, lW1, lH1, QBrush(QColor(200,0,0)));

			// Display download
			lH2 = -(int)(lDYStep*lValues[lX].download);
			lX2 = (int)(lXOrigin+lXStep*lX+lXStep+1);
			lY2 = lYOrigin;
			lW2 = 3;
			p.fillRect(lX2, lY2, lW2, lH2, QBrush(QColor(0,0,200)));

		}

		// Draw axes
		p.setPen(QPen(QColor(0,0,0)));
		p.drawLine(lXOrigin, lYOrigin-lHeight, lXOrigin, lYOrigin);
		p.lineTo(lXOrigin+lWidth, lYOrigin);
		p.drawLine(lXOrigin+lWidth, lYOrigin-lHeight, lXOrigin+lWidth, lYOrigin);
		p.setFont(QFont("Helvetica", 8));
		for (lY=0; lY<5; lY++)
		{
			// Upload
			lGrad = (double)(lY*((double)lHeight/4)/lUYStep);
			lType=0; while (lGrad>=1024) {lGrad=lGrad/1024; lType++;}
			lValue.sprintf("%0.2f", lGrad);
			// Cut at the first 0 after the .
			if (lValue.find('0', lValue.find('.')+1)>0) lValue.truncate(lValue.find('0', lValue.find('.')+1));
			if (lValue.right(1)==".") lValue.truncate(lValue.length()-1);
			// Add unity
			switch(lType)
			{
				case 0 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("b "));}; break; 	// Bytes
				case 1 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("Kb"));}; break; 	// Kb
				case 2 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("Mb"));}; break; 	// Mb
				case 3 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("Gb"));}; break; 	// Gb
				case 4 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("Tb"));}; break; 	// Tb
				default: lValue.sprintf("%s%s", (const char *)lValue, i18n("b "));
			}
			p.setPen(QPen(QColor(200,0,0)));
			p.drawLine(lXOrigin-2, lYOrigin-lY*((float)lHeight/4), lXOrigin-1, lYOrigin-lY*((float)lHeight/4));
			p.drawText(lXOrigin-31, lYOrigin-6-lY*((float)lHeight/4), 30, 10, AlignVCenter|AlignRight, lValue);

			// Download
			lGrad = (double)(lY*((double)lHeight/4)/lDYStep);
			lType=0; while (lGrad>=1024) {lGrad=lGrad/1024; lType++;}
			lValue.sprintf("%0.2f", lGrad);
			// Cut at the first 0 after the .
			if (lValue.find('0', lValue.find('.')+1)>0) lValue.truncate(lValue.find('0', lValue.find('.')+1));
			if (lValue.right(1)==".") lValue.truncate(lValue.length()-1);
			switch(lType)
			{
				case 0 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("b "));}; break; 	// Bytes
				case 1 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("Kb"));}; break; 	// Kb
				case 2 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("Mb"));}; break; 	// Mb
				case 3 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("Gb"));}; break; 	// Gb
				case 4 : {lValue.sprintf("%s%s", (const char *)lValue, i18n("Tb"));}; break; 	// Tb
				default: lValue.sprintf("%s%s", (const char *)lValue, i18n("b "));
			}
			p.setPen(QPen(QColor(0,0,200)));
			p.drawLine(lXOrigin+lWidth+1, lYOrigin-lY*((float)lHeight/4), lXOrigin+lWidth+2, lYOrigin-lY*((float)lHeight/4));
			p.drawText(lXOrigin+lWidth+5, lYOrigin-6-lY*((float)lHeight/4), 30, 10, AlignVCenter|AlignLeft, lValue);
		}		

		QPixmap		lUPixmap((const char **)upload_xpm);
		p.drawPixmap(1, (height()-lUPixmap.height())/2, lUPixmap);

		QPixmap		lDPixmap((const char **)download_xpm);
		p.drawPixmap(width()-lDPixmap.width()-2, (height()-lDPixmap.height())/2, lDPixmap);
	}
}

void KStatGraph::drawGraph(int iMonth, int iYear)
{
	mMonth 	= iMonth;
	mYear 	= iYear;

	update();
}
